@@ -30,8 +30,9 @@
 #include "updateHap.hpp"  // chromPainting
 #include "dEploidIO.hpp"
 #include "ibd.hpp"
+#include "lasso/dEploidLasso.hpp"
 
-DEploidIO::DEploidIO(){
+DEploidIO::DEploidIO() {
     this->init();
 }
 
@@ -55,16 +56,20 @@ DEploidIO::DEploidIO(int argc, char *argv[]) {
 }
 
 
-DEploidIO::~DEploidIO(){
-    if ( this->excludedMarkers != NULL ){
+DEploidIO::~DEploidIO() {
+    if (this->isCopied()){
+        return;
+    }
+
+    if ( this->excludedMarkers != NULL ) {
         delete this->excludedMarkers;
     }
 
-    if ( this->vcfReaderPtr_ != NULL ){
+    if ( this->vcfReaderPtr_ != NULL ) {
         delete this->vcfReaderPtr_;
     }
 
-    if ( this->panel != NULL ){
+    if ( this->panel != NULL ) {
         delete panel;
     }
 }
@@ -79,7 +84,7 @@ void DEploidIO::core() {
     this->reInit(); // Reset to defalt values before parsing
     this->parse();
 
-    if ( this->help() || version() ){
+    if ( this->help() || version() ) {
         return;
     }
 
@@ -89,6 +94,8 @@ void DEploidIO::core() {
 
 
 void DEploidIO::init() {
+    this->setDoPrintLassoPanel(false);
+    this->setIsCopied(false);
     this->setDoExportRecombProb(false);
     this->setrandomSeedWasGiven(false);
     this->setCompressVcf(false);
@@ -117,6 +124,8 @@ void DEploidIO::init() {
     this->setDoLsPainting( false );
     this->setDoIbdPainting( false );
     this->setUseIBD( false );
+    this->setUseIbdOnly(false);
+    this->setUseLasso( false );
     this->setDoExportSwitchMissCopy ( true );
     this->setDoAllowInbreeding( false );
     this->mcmcBurn_ = 0.5;
@@ -146,14 +155,22 @@ void DEploidIO::init() {
     #else
         dEploidGitVersion_ = "";
     #endif
+
+    #ifdef DEPLOIDVERSION
+        lassoGitVersion_ = LASSOVERSION;
+    #else
+        lassoGitVersion_ = "";
+    #endif
+
+
 }
 
 
-void DEploidIO::getTime( bool isStartingTime ){
+void DEploidIO::getTime( bool isStartingTime ) {
     time_t now = time(0);
     // convert now to string form
     char* dt = ctime(&now);
-    if ( isStartingTime ){
+    if ( isStartingTime ) {
         startingTime_ = string(dt);
     } else {
         endTime_ = string(dt);
@@ -172,33 +189,33 @@ void DEploidIO::reInit() {
 }
 
 
-void DEploidIO::finalize(){
-    if ( this->doIbdPainting() | this->doComputeLLK() ){
-        if (!initialPropWasGiven()){
+void DEploidIO::finalize() {
+    if ( this->doIbdPainting() | this->doComputeLLK() ) {
+        if (!initialPropWasGiven()) {
             throw InitialPropUngiven("");
         }
     }
 
-    if ( this->useIBD() && this->kStrain() == 1){
+    if ( this->useIBD() && this->kStrain() == 1) {
         throw InvalidK();
     }
 
-    if ( this->compressVcf() && !this->doExportVcf() ){
+    if ( this->compressVcf() && !this->doExportVcf() ) {
         throw VcfOutUnSpecified("");
     }
 
-    if ( !this->randomSeedWasGiven_ ){
+    if ( !this->randomSeedWasGiven_ ) {
         this->set_seed( (unsigned)(time(0)) );
     }
 
-    if ( this->excludeSites() ){
+    if ( this->excludeSites() ) {
         excludedMarkers = new ExcludeMarker();
         excludedMarkers->readFromFile(excludeFileName_.c_str());
     }
 
-    if ( useVcf() ){ // read vcf files, and parse it to refCount and altCount
+    if ( useVcf() ) { // read vcf files, and parse it to refCount and altCount
         this->vcfReaderPtr_ = new VcfReader (vcfFileName_ );
-        if ( this->excludeSites() ){
+        if ( this->excludeSites() ) {
             this->vcfReaderPtr_->findAndKeepMarkers (excludedMarkers);
         }
 
@@ -208,14 +225,14 @@ void DEploidIO::finalize(){
     } else {
         TxtReader ref;
         ref.readFromFile(refFileName_.c_str());
-        if ( this->excludeSites() ){
+        if ( this->excludeSites() ) {
             ref.findAndKeepMarkers( excludedMarkers );
         }
         this->refCount_ = ref.info_;
 
         TxtReader alt;
         alt.readFromFile(altFileName_.c_str());
-        if ( this->excludeSites() ){
+        if ( this->excludeSites() ) {
             alt.findAndKeepMarkers( excludedMarkers );
         }
         this->altCount_ = alt.info_;
@@ -223,7 +240,7 @@ void DEploidIO::finalize(){
 
     TxtReader plaf;
     plaf.readFromFile(plafFileName_.c_str());
-    if ( this->excludeSites() ){
+    if ( this->excludeSites() ) {
         plaf.findAndKeepMarkers( excludedMarkers );
     }
     this->plaf_ = plaf.info_;
@@ -233,11 +250,11 @@ void DEploidIO::finalize(){
 
     this->nLoci_ = refCount_.size();
 
-    if ( this->nLoci_ != this->plaf_.size() ){
+    if ( this->nLoci_ != this->plaf_.size() ) {
         throw LociNumberUnequal( this->plafFileName_ );
     }
 
-    if ( this->nLoci_ != this->altCount_.size() ){
+    if ( this->nLoci_ != this->altCount_.size() ) {
         throw LociNumberUnequal( this->altFileName_ );
     }
     (void)removeFilesWithSameName();
@@ -262,18 +279,24 @@ void DEploidIO::finalize(){
 }
 
 
-void DEploidIO::removeFilesWithSameName(){
+void DEploidIO::removeFilesWithSameName() {
     strExportProp = this->prefix_ + ".prop";
     strExportLLK = this->prefix_ + ".llk";
     strExportHap = this->prefix_ + ".hap";
 
-    strIbdExportProp = this->prefix_ + ".ibd.prop";
-    strIbdExportLLK = this->prefix_ + ".ibd.llk";
-    strIbdExportHap = this->prefix_ + ".ibd.hap";
-    strIbdExportProbs = this->prefix_ + ".ibd.probs";
+    if (this->useIbdOnly()) {
+        strIbdExportProp = this->prefix_ + ".prop";
+        strIbdExportLLK = this->prefix_ + ".llk";
+        strIbdExportHap = this->prefix_ + ".hap";
+    } else {
+        strIbdExportProp = this->prefix_ + ".ibd.prop";
+        strIbdExportLLK = this->prefix_ + ".ibd.llk";
+        strIbdExportHap = this->prefix_ + ".ibd.hap";
+        strIbdExportProbs = this->prefix_ + ".ibd.probs";
+    }
 
     strExportVcf = this->prefix_ + ".vcf";
-    if ( compressVcf() ){
+    if ( compressVcf() ) {
         strExportVcf += ".gz";
     }
     strExportLog =  this->prefix_ + ((this->doLsPainting()) ? ".painting":"") + ".log";
@@ -281,8 +304,8 @@ void DEploidIO::removeFilesWithSameName(){
 
     strExportExtra = this->prefix_ + ".extra";
 
-    if ( this->doLsPainting() == false ){
-        if (this->useIBD()){
+    if ( this->doLsPainting() == false ) {
+        if (this->useIBD()) {
             remove(strIbdExportProp.c_str());
             remove(strIbdExportLLK.c_str());
             remove(strIbdExportHap.c_str());
@@ -295,10 +318,10 @@ void DEploidIO::removeFilesWithSameName(){
         remove(strIbdExportProbs.c_str());
     }
 
-    if (this->doLsPainting() || this->doExportPostProb() ){
-        if (this->useIBD()){
+    if (this->doLsPainting() || this->doExportPostProb() ) {
+        if (this->useIBD()) {
             strIbdExportSingleFwdProbPrefix = this->prefix_ + ".ibd.single";
-            for ( size_t i = 0; i < this->kStrain_ ; i++ ){
+            for ( size_t i = 0; i < this->kStrain_ ; i++ ) {
                 string tmpStrExportSingleFwdProb = strIbdExportSingleFwdProbPrefix + to_string(i);
                 remove(tmpStrExportSingleFwdProb.c_str());
             }
@@ -306,7 +329,7 @@ void DEploidIO::removeFilesWithSameName(){
             remove(strIbdExportPairFwdProb.c_str());
         }
         strExportSingleFwdProbPrefix = this->prefix_ + ".single";
-        for ( size_t i = 0; i < this->kStrain_ ; i++ ){
+        for ( size_t i = 0; i < this->kStrain_ ; i++ ) {
             string tmpStrExportSingleFwdProb = strExportSingleFwdProbPrefix + to_string(i);
             remove(tmpStrExportSingleFwdProb.c_str());
         }
@@ -319,46 +342,46 @@ void DEploidIO::removeFilesWithSameName(){
 }
 
 
-void DEploidIO::parse (){
+void DEploidIO::parse () {
     do {
         if (*argv_i == "-ref") {
-            if ( this->useVcf() ){
+            if ( this->useVcf() ) {
                 throw ( FlagsConflict((*argv_i) , "-vcf") );
             }
             this->readNextStringto ( this->refFileName_ ) ;
         } else if (*argv_i == "-alt") {
-            if ( this->useVcf() ){
+            if ( this->useVcf() ) {
                 throw ( FlagsConflict((*argv_i) , "-vcf") );
             }
             this->readNextStringto ( this->altFileName_ ) ;
         } else if (*argv_i == "-vcf") {
-            if ( this->refFileName_.size() > 0 || this->altFileName_.size() > 0 ){
+            if ( this->refFileName_.size() > 0 || this->altFileName_.size() > 0 ) {
                 throw ( FlagsConflict((*argv_i) , "-ref or -alt") );
             }
             this->setUseVcf(true);
             this->readNextStringto ( this->vcfFileName_ ) ;
-        } else if (*argv_i == "-vcfOut"){
+        } else if (*argv_i == "-vcfOut") {
             this->setDoExportVcf (true);
         } else if (*argv_i == "-plaf") {
             this->readNextStringto ( this->plafFileName_ ) ;
         } else if (*argv_i == "-panel") {
-            if ( this->usePanel() == false ){
+            if ( this->usePanel() == false ) {
                 throw ( FlagsConflict((*argv_i) , "-noPanel") );
             }
             this->readNextStringto ( this->panelFileName_ ) ;
-        } else if (*argv_i == "-noPanel"){
-            if ( usePanel() && this->panelFileName_.size() > 0 ){
+        } else if (*argv_i == "-noPanel") {
+            if ( usePanel() && this->panelFileName_.size() > 0 ) {
                 throw ( FlagsConflict((*argv_i) , "-panel") );
             }
-            if ( doExportPostProb() ){
+            if ( doExportPostProb() ) {
                 throw ( FlagsConflict((*argv_i) , "-exportPostProb") );
             }
-            if ( doAllowInbreeding() ){
+            if ( doAllowInbreeding() ) {
                 throw ( FlagsConflict((*argv_i) , "-inbreeding") );
             }
             this->setUsePanel(false);
             this->setDoExportSwitchMissCopy ( false );
-        } else if (*argv_i == "-exclude"){
+        } else if (*argv_i == "-exclude") {
             this->setExcludeSites( true );
             this->readNextStringto ( this->excludeFileName_ ) ;
         } else if (*argv_i == "-o") {
@@ -369,12 +392,12 @@ void DEploidIO::parse (){
             this->setKStrainWasManuallySet(true);
             this->setKstrain(readNextInput<size_t>());
 
-            if ( this->kStrainWasSetByHap() && this->kStrain() != this->initialHap[0].size() ){
+            if ( this->kStrainWasSetByHap() && this->kStrain() != this->initialHap[0].size() ) {
                 string hint = string(" k = ") + to_string(this->kStrain()) + ", " + this->initialHapFileName_ + " suggests otherwise";
                 throw NumOfPropNotMatchNumStrain(hint);
             }
 
-            if ( this->initialPropWasGiven() && this->kStrain_ != initialProp.size() ){
+            if ( this->initialPropWasGiven() && this->kStrain_ != initialProp.size() ) {
                 string hint = string(" k = ") + to_string(kStrain_) + ", flag -initialP suggests otherwise";;
                 throw NumOfPropNotMatchNumStrain(hint);
             }
@@ -383,12 +406,12 @@ void DEploidIO::parse (){
             this->nMcmcSample_ = readNextInput<size_t>() ;
         } else if ( *argv_i == "-burn" ) {
             this->mcmcBurn_ = readNextInput<double>() ;
-            if ( this->mcmcBurn_ < 0 || this->mcmcBurn_ > 1){
+            if ( this->mcmcBurn_ < 0 || this->mcmcBurn_ > 1) {
                 throw ( OutOfRange ("-burn", *argv_i) );
             }
         } else if ( *argv_i == "-miss" ) {
             this->missCopyProb_ = readNextInput<double>() ;
-            if ( this->missCopyProb_ < 0 || this->missCopyProb_ > 1){
+            if ( this->missCopyProb_ < 0 || this->missCopyProb_ > 1) {
                 throw ( OutOfRange ("-miss", *argv_i) );
             }
         } else if ( *argv_i == "-c" ) {
@@ -402,7 +425,7 @@ void DEploidIO::parse (){
         } else if ( *argv_i == "-recomb" ) {
             this->constRecombProb_ = readNextInput<double>();
             this->useConstRecomb_ = true;
-            if ( this->constRecombProb_ < 0 || this->constRecombProb_ > 1){
+            if ( this->constRecombProb_ < 0 || this->constRecombProb_ > 1) {
                 throw ( OutOfRange ("-recomb", *argv_i) );
             }
         } else if ( *argv_i == "-printRecomb" ) {
@@ -418,66 +441,74 @@ void DEploidIO::parse (){
         } else if ( *argv_i == "-forbidUpdatePair" ) {
             this->setDoUpdatePair( false );
         } else if ( *argv_i == "-inbreeding" ) {
-            if ( this->usePanel() == false ){
+            if ( this->usePanel() == false ) {
                 throw ( FlagsConflict((*argv_i) , "-noPanel") );
             }
             this->setDoAllowInbreeding( true );
             this->setDoExportPostProb( true );
         } else if ( *argv_i == "-exportPostProb" ) {
-            if ( this->usePanel() == false ){
+            if ( this->usePanel() == false ) {
                 throw ( FlagsConflict((*argv_i) , "-noPanel") );
             }
             this->setDoExportPostProb( true );
         } else if ( *argv_i == "-painting" ) {
-            if ( this->usePanel() == false ){
+            if ( this->usePanel() == false ) {
                 throw ( FlagsConflict((*argv_i) , "-noPanel") );
             }
-            if ( this->initialHapWasGiven() == true ){
+            if ( this->initialHapWasGiven() == true ) {
                 throw ( FlagsConflict((*argv_i) , "-initialHap") );
             }
             this->readNextStringto ( this->initialHapFileName_ ) ;
             this->setDoLsPainting( true );
             this->readInitialHaps();
-        } else if ( *argv_i == "-ibd" ){
+        } else if ( *argv_i == "-ibd" ) {
             this->setUseIBD(true);
-        } else if ( *argv_i == "-computeLLK" ){
+        } else if ( *argv_i == "-ibdonly" ) {
+            this->setUseIBD(true);
+            this->setUseIbdOnly(true);
+        } else if ( *argv_i == "-lasso" ) {
+            this->setUseLasso(true);
+            this->setDoUpdateProp(false);
+        } else if ( *argv_i == "-writePanel" ) {
+            this->setDoPrintLassoPanel(true);
+        } else if ( *argv_i == "-computeLLK" ) {
             this->setDoComputeLLK( true );
-        } else if ( *argv_i == "-ibdPainting" ){
+        } else if ( *argv_i == "-ibdPainting" ) {
             this->setDoIbdPainting( true );
-        } else if ( *argv_i == "-skipCheckingInitialP" ){
+        } else if ( *argv_i == "-skipCheckingInitialP" ) {
             this->setPleaseCheckInitialP(false);
-        } else if ( *argv_i == "-initialP" ){
+        } else if ( *argv_i == "-initialP" ) {
             this->readInitialProportions();
             this->setInitialPropWasGiven( true );
 
             // If the k was set manually, check
-            if ( this->kStrainWasManuallySet() && this->kStrain_ != initialProp.size() ){
+            if ( this->kStrainWasManuallySet() && this->kStrain_ != initialProp.size() ) {
                 string hint = string(" k = ") + to_string(kStrain_);
                 throw NumOfPropNotMatchNumStrain(hint);
             }
 
             // If the k was set by initial Hap, check
-            if ( this->kStrainWasSetByHap() && this->kStrain() != this->initialProp.size() ){
+            if ( this->kStrainWasSetByHap() && this->kStrain() != this->initialProp.size() ) {
                 string hint = string(" k = ") + to_string(this->kStrain()) + ", " + this->initialHapFileName_ + " suggests otherwise";
                 throw NumOfPropNotMatchNumStrain(hint);
             }
 
             this->setKstrain(this->initialProp.size());
-        } else if ( *argv_i == "-initialHap" ){
-            if ( this->doLsPainting() == true ){
+        } else if ( *argv_i == "-initialHap" ) {
+            if ( this->doLsPainting() == true ) {
                 throw ( FlagsConflict((*argv_i) , "-painting") );
             }
             this->readNextStringto ( this->initialHapFileName_ ) ;
             this->setInitialHapWasGiven(true);
             this->readInitialHaps();
-        } else if ( *argv_i == "-seed"){
+        } else if ( *argv_i == "-seed") {
             this->set_seed( readNextInput<size_t>() );
             this->setrandomSeedWasGiven( true );
-        } else if ( *argv_i == "-z" ){
+        } else if ( *argv_i == "-z" ) {
             this->setCompressVcf(true);
-        } else if ( *argv_i == "-h" || *argv_i == "-help"){
+        } else if ( *argv_i == "-h" || *argv_i == "-help") {
             this->set_help(true);
-        } else if ( *argv_i == "-v" || *argv_i == "-version"){
+        } else if ( *argv_i == "-v" || *argv_i == "-version") {
             this->setVersion(true);
         } else {
             throw ( UnknowArg((*argv_i)) );
@@ -486,20 +517,20 @@ void DEploidIO::parse (){
 }
 
 
-void DEploidIO::checkInput(){
+void DEploidIO::checkInput() {
 
-    if ( this->refFileName_.size() == 0 && this->useVcf() == false ){
+    if ( this->refFileName_.size() == 0 && this->useVcf() == false ) {
         throw FileNameMissing ( "Ref count" );}
-    if ( this->altFileName_.size() == 0 && this->useVcf() == false ){
+    if ( this->altFileName_.size() == 0 && this->useVcf() == false ) {
         throw FileNameMissing ( "Alt count" );}
-    if ( this->plafFileName_.size() == 0 ){
+    if ( this->plafFileName_.size() == 0 ) {
         throw FileNameMissing ( "PLAF" );}
-    if ( usePanel() && this->panelFileName_.size() == 0 && !this->doIbdPainting() && !this->doComputeLLK() ){
+    if ( usePanel() && this->panelFileName_.size() == 0 && !this->doIbdPainting() && !this->doComputeLLK() ) {
         throw FileNameMissing ( "Reference panel" );}
-    if ( this->initialPropWasGiven() && ( abs(sumOfVec(initialProp) - 1.0) > 0.00001 ) && this->pleaseCheckInitialP() ){
+    if ( this->initialPropWasGiven() && ( abs(sumOfVec(initialProp) - 1.0) > 0.00001 ) && this->pleaseCheckInitialP() ) {
         throw SumOfPropNotOne ( to_string(sumOfVec(initialProp)) );}
-    if ( this->initialPropWasGiven() ){
-        if ( this->kStrainWasManuallySet() == true ){
+    if ( this->initialPropWasGiven() ) {
+        if ( this->kStrainWasManuallySet() == true ) {
         } else {
             // set k strain by proportion length
         }
@@ -507,7 +538,7 @@ void DEploidIO::checkInput(){
 }
 
 
-void DEploidIO::readInitialProportions(){
+void DEploidIO::readInitialProportions() {
     string tmpFlag = *argv_i;
     ++argv_i;
     if (argv_i == argv_.end() || (*argv_i)[0] == '-' ) {
@@ -518,7 +549,7 @@ void DEploidIO::readInitialProportions(){
         try {
             double tmp = convert<double>(*argv_i);
             this->initialProp.push_back(tmp);
-        } catch (WrongType e) {
+        } catch (const WrongType &e) {
             --argv_i;
             break;
         }
@@ -530,24 +561,25 @@ void DEploidIO::readInitialProportions(){
 }
 
 
-void DEploidIO::readNextStringto( string &readto ){
+void DEploidIO::readNextStringto( string &readto ) {
     string tmpFlag = *argv_i;
     ++argv_i;
-    if (argv_i == argv_.end() || (*argv_i)[0] == '-' ){
+    if (argv_i == argv_.end() || (*argv_i)[0] == '-' ) {
         throw NotEnoughArg(tmpFlag);
     }
     readto = *argv_i;
 }
 
 
-void DEploidIO::printVersion(std::ostream& out){
+void DEploidIO::printVersion(std::ostream& out) {
     out << endl
         << "dEploid " << VERSION
         << endl
-        << "Git commit: " << dEploidGitVersion_ << endl;
+        << "Git commit (DEploid): " << dEploidGitVersion_ << endl
+        << "Git commit (Lasso): " << lassoGitVersion_ << endl;
 }
 
-void DEploidIO::printHelp(std::ostream& out){
+void DEploidIO::printHelp(std::ostream& out) {
     out << endl
         << "dEploid " << VERSION
         << endl
@@ -582,6 +614,7 @@ void DEploidIO::printHelp(std::ostream& out){
     out << "./dEploid -vcf data/testData/PG0390-C.test.vcf -exclude data/testData/labStrains.test.exclude.txt -plaf data/testData/labStrains.test.PLAF.txt -o PG0390-CPanelExclude -panel data/testData/labStrains.test.panel.txt -painting PG0390-CPanelExclude.hap" << endl;
     out << "./dEploid -vcf data/testData/PG0390-C.test.vcf -plaf data/testData/labStrains.test.PLAF.txt -o PG0390-CNopanel -noPanel -k 2 -ibd -nSample 250 -rate 8 -burn 0.67" <<endl;
     out << "./dEploid -vcf data/testData/PG0390-C.test.vcf -plaf data/testData/labStrains.test.PLAF.txt -o PG0390-CNopanel -ibdPainting -initialP 0.2 0.8" <<endl;
+    out << "./dEploid -vcf data/testData/PG0390-C.test.vcf -exclude data/testData/labStrains.test.exclude.txt -plaf data/testData/labStrains.test.PLAF.txt -o PG0390-CLassoExclude -panel data/testData/labStrains.test.panel.txt -lasso -initialP 0.2 0.8 -writePanel" << endl;
 }
 
 
@@ -591,7 +624,7 @@ std::ostream& operator<< (std::ostream& stream, const DEploidIO& dEploidIO) {
 }
 
 
-void DEploidIO::readInitialHaps(){
+void DEploidIO::readInitialHaps() {
     assert( this->initialHap.size() == 0 );
     InitialHaplotypes initialHapToBeRead;
     initialHapToBeRead.readFromFile(this->initialHapFileName_.c_str());
@@ -599,12 +632,12 @@ void DEploidIO::readInitialHaps(){
     assert (this->initialHap.size() == 0 );
     this->initialHap = initialHapToBeRead.content_;
 
-    if ( this->kStrainWasManuallySet() && this->kStrain()!= initialHapToBeRead.truePanelSize() ){
+    if ( this->kStrainWasManuallySet() && this->kStrain()!= initialHapToBeRead.truePanelSize() ) {
         string hint = string(" k = ") + to_string(this->kStrain()) + ", " + this->initialHapFileName_ + " suggests otherwise";
         throw NumOfPropNotMatchNumStrain(hint);
     }
 
-    if ( this->kStrainWasSetByProp() && this->kStrain() != initialHapToBeRead.truePanelSize() ){
+    if ( this->kStrainWasSetByProp() && this->kStrain() != initialHapToBeRead.truePanelSize() ) {
         string hint = string(" k = ") + to_string(kStrain_) + ", flag -initialP suggests otherwise";;
         throw NumOfPropNotMatchNumStrain(hint);
     }
@@ -614,13 +647,13 @@ void DEploidIO::readInitialHaps(){
 }
 
 
-vector <double> DEploidIO::computeExpectedWsafFromInitialHap(){
+vector <double> DEploidIO::computeExpectedWsafFromInitialHap() {
     // Make this a separate function
     // calculate expected wsaf
     vector <double> expectedWsaf (this->initialHap.size(), 0.0);
-    for ( size_t i = 0; i < this->initialHap.size(); i++ ){
+    for ( size_t i = 0; i < this->initialHap.size(); i++ ) {
         assert( kStrain_ == this->initialHap[i].size() );
-        for ( size_t k = 0; k < this->kStrain_; k++){
+        for ( size_t k = 0; k < this->kStrain_; k++) {
             expectedWsaf[i] += this->initialHap[i][k] * finalProp[k];
         }
         assert ( expectedWsaf[i] >= 0 );
@@ -630,13 +663,13 @@ vector <double> DEploidIO::computeExpectedWsafFromInitialHap(){
 }
 
 
-void DEploidIO::computeLLKfromInitialHap(){
-    for ( auto const& value: this->initialProp ){
+void DEploidIO::computeLLKfromInitialHap() {
+    for ( auto const& value: this->initialProp ) {
         this->finalProp.push_back(value);
     }
 
     vector <double> expectedWsaf = computeExpectedWsafFromInitialHap();
-    if (expectedWsaf.size() != this->refCount_.size()){
+    if (expectedWsaf.size() != this->refCount_.size()) {
         throw LociNumberUnequal("Hap length differs from data!");
     }
     vector <double> llk = calcLLKs ( this->refCount_, this->altCount_, expectedWsaf, 0, expectedWsaf.size(), this->scalingFactor());
@@ -644,18 +677,18 @@ void DEploidIO::computeLLKfromInitialHap(){
 }
 
 
-void DEploidIO::chromPainting(){
+void DEploidIO::chromPainting() {
     dout << "Painting haplotypes in" << this->initialHapFileName_ <<endl;
 
-    if ( this->initialPropWasGiven() == false ){
+    if ( this->initialPropWasGiven() == false ) {
         clog << "Initial proportion was not specified. Set even proportions" << endl;
         double evenProp = 1.0 / (double)this->kStrain();
-        for ( size_t i = 0; i < this->kStrain(); i++){
+        for ( size_t i = 0; i < this->kStrain(); i++) {
             this->initialProp.push_back(evenProp);
         }
     }
 
-    for ( auto const& value: this->initialProp ){
+    for ( auto const& value: this->initialProp ) {
         this->finalProp.push_back(value);
     }
 
@@ -664,9 +697,9 @@ void DEploidIO::chromPainting(){
     // Export the p'
     // Make this a separate class
     //vector < vector <double> > hap;
-    //for ( size_t siteI = 0; siteI < decovolutedStrainsToBeRead.content_.size(); siteI++ ){
+    //for ( size_t siteI = 0; siteI < decovolutedStrainsToBeRead.content_.size(); siteI++ ) {
         //vector <double> tmpHap;
-        //for ( size_t tmpk = 0; tmpk < this->kStrain_; tmpk++ ){
+        //for ( size_t tmpk = 0; tmpk < this->kStrain_; tmpk++ ) {
             //tmpHap.push_back(decovolutedStrainsToBeRead.content_[siteI][tmpk]);
         //}
         //hap.push_back(tmpHap);
@@ -678,16 +711,16 @@ void DEploidIO::chromPainting(){
 
     MersenneTwister tmpRg(this->randomSeed());
 
-    if ( this->doAllowInbreeding() == true ){
+    if ( this->doAllowInbreeding() == true ) {
         this->panel->initializeUpdatePanel(this->panel->truePanelSize()+kStrain_-1);
     }
 
-    for ( size_t tmpk = 0; tmpk < this->kStrain_; tmpk++ ){
-        if ( this->doAllowInbreeding() == true ){
+    for ( size_t tmpk = 0; tmpk < this->kStrain_; tmpk++ ) {
+        if ( this->doAllowInbreeding() == true ) {
             this->panel->updatePanelWithHaps(this->panel->truePanelSize()+kStrain_-1, tmpk, this->initialHap);
         }
 
-        for ( size_t chromi = 0 ; chromi < this->indexOfChromStarts_.size(); chromi++ ){
+        for ( size_t chromi = 0 ; chromi < this->indexOfChromStarts_.size(); chromi++ ) {
             size_t start = this->indexOfChromStarts_[chromi];
             size_t length = this->position_[chromi].size();
             dout << "Painting Chrom "<< chromi << " from site "<< start << " to " << start+length << endl;
@@ -701,7 +734,7 @@ void DEploidIO::chromPainting(){
                                       this->panel, this->missCopyProb_, this->scalingFactor(),
                                       tmpk);
 
-            if ( this->doAllowInbreeding() == true ){
+            if ( this->doAllowInbreeding() == true ) {
                 updatingSingle.setPanelSize(this->panel->inbreedingPanelSize());
             }
             updatingSingle.painting( refCount_, altCount_, expectedWsaf, this->finalProp, this->initialHap);
@@ -712,17 +745,17 @@ void DEploidIO::chromPainting(){
 }
 
 
-void DEploidIO::readPanel(){
-    if ( this->usePanel() == false ){
+void DEploidIO::readPanel() {
+    if ( this->usePanel() == false ) {
         return;
     }
-    if ( this->doIbdPainting() | this->doComputeLLK() ){
+    if ( this->doIbdPainting() | this->doComputeLLK() ) {
         return;
     }
 
     panel = new Panel();
     panel->readFromFile(this->panelFileName_.c_str());
-    if ( this->excludeSites() ){
+    if ( this->excludeSites() ) {
         panel->findAndKeepMarkers( this->excludedMarkers );
     }
 
@@ -731,27 +764,91 @@ void DEploidIO::readPanel(){
 }
 
 
-DEploidIO::DEploidIO(const DEploidIO &currentDEploidIO){
-    // This is not working! to be improved
-    //cout << this->refCount_.size() << endl;
-    this->refCount_ = currentDEploidIO.refCount_;
-    //cout << this->refCount_.size() << endl;
+DEploidIO::DEploidIO(const DEploidIO &cpFrom) {
+    this->setIsCopied(true);
+    this->setDoExportRecombProb(cpFrom.doExportRecombProb());
+    this->setrandomSeedWasGiven(cpFrom.randomSeedWasGiven());
+    this->setCompressVcf(cpFrom.compressVcf());
+    this->setInitialPropWasGiven(cpFrom.initialPropWasGiven());
+    this->setInitialHapWasGiven(cpFrom.initialHapWasGiven());
+    this->initialProp = vector <double> (cpFrom.initialProp.begin(),
+                                         cpFrom.initialProp.end());
+    this->setPleaseCheckInitialP(cpFrom.pleaseCheckInitialP());
+    this->setExcludeSites(cpFrom.excludeSites());
+    this->excludedMarkers = cpFrom.excludedMarkers;
+    this->panel = cpFrom.panel;
+    this->set_seed(cpFrom.randomSeed_);
+    this->set_help(cpFrom.help());
+    this->setVersion(cpFrom.version());
+    this->setUsePanel(cpFrom.usePanel());
+    this->precision_ = cpFrom.precision_;
+    this->prefix_ = cpFrom.prefix_;
+    this->setKStrainWasManuallySet(cpFrom.kStrainWasManuallySet());
+    this->setKStrainWasSetByHap(cpFrom.kStrainWasSetByHap());
+    this->setKStrainWasSetByProp(cpFrom.kStrainWasSetByProp());
+    this->setKstrain(cpFrom.kStrain());
+    this->nMcmcSample_ = cpFrom.nMcmcSample();
+    this->setDoUpdateProp(cpFrom.doUpdateProp());
+    this->setDoUpdatePair(cpFrom.doUpdatePair());
+    this->setDoUpdateSingle(cpFrom.doUpdateSingle());
+    this->setDoExportPostProb(cpFrom.doExportPostProb());
+    this->setDoLsPainting(cpFrom.doLsPainting());
+    this->setDoIbdPainting(cpFrom.doIbdPainting());
+    this->setUseIBD(cpFrom.useIBD());
+    this->setUseIbdOnly(cpFrom.useIbdOnly());
+    this->setUseLasso(cpFrom.useLasso());
+    this->setDoExportSwitchMissCopy(cpFrom.doExportSwitchMissCopy());
+    this->setDoAllowInbreeding(cpFrom.doAllowInbreeding());
+    this->mcmcBurn_ = cpFrom.mcmcBurn_;
+    this->mcmcMachineryRate_ = cpFrom.mcmcMachineryRate_;
+    this->missCopyProb_ = cpFrom.missCopyProb_;
+    this->useConstRecomb_ = cpFrom.useConstRecomb();
+    this->setForbidCopyFromSame(cpFrom.forbidCopyFromSame());
+    this->constRecombProb_ = cpFrom.constRecombProb();
+    this->averageCentimorganDistance_ = cpFrom.averageCentimorganDistance();
+    this->setScalingFactor(cpFrom.scalingFactor());
+    this->setParameterG(cpFrom.parameterG());
+    this->setParameterSigma(cpFrom.parameterSigma());
+    this->setIBDSigma(cpFrom.ibdSigma());
+    this->setUseVcf(cpFrom.useVcf());
+    this->vcfReaderPtr_ = cpFrom.vcfReaderPtr_;
+    this->setDoExportVcf(cpFrom.doExportVcf());
+    this->setDoComputeLLK(cpFrom.doComputeLLK());
+    this->setNLoci(cpFrom.nLoci());
+    this->refCount_ = vector <double> (cpFrom.refCount_.begin(),
+                                       cpFrom.refCount_.end());
+    this->altCount_ = vector <double> (cpFrom.altCount_.begin(),
+                                       cpFrom.altCount_.end());
+    this->plaf_ = vector <double> (cpFrom.plaf_.begin(),
+                                   cpFrom.plaf_.end());
+    this->chrom_ = vector <string> (cpFrom.chrom_.begin(),
+                                   cpFrom.chrom_.end());
+    this->position_ = vector < vector <int> > (cpFrom.position_.begin(),
+                                   cpFrom.position_.end());
+    this->indexOfChromStarts_ = vector <size_t> (cpFrom.indexOfChromStarts_.begin(),
+                                   cpFrom.indexOfChromStarts_.end());
+    this->strExportProp = cpFrom.strExportProp;
+    this->strExportLLK = cpFrom.strExportLLK;
+    this->strExportHap = cpFrom.strExportHap;
+    this->strIbdExportProp = cpFrom.strIbdExportProp;
+    this->strIbdExportLLK = cpFrom.strIbdExportLLK;
+    this->strIbdExportHap = cpFrom.strIbdExportHap;
 }
 
 
-void DEploidIO::getIBDprobsIntegrated(vector < vector <double> > &prob){
-    if (prob.size() !=  this->nLoci()){
+void DEploidIO::getIBDprobsIntegrated(vector < vector <double> > &prob) {
+    if (prob.size() !=  this->nLoci()) {
         throw InvalidInput("Invalid probabilities! Check size!");
     }
 
     assert(this->ibdProbsIntegrated.size() == 0);
 
-    for (size_t i = 0; i < prob[0].size(); i++){
+    for (size_t i = 0; i < prob[0].size(); i++) {
         this->ibdProbsIntegrated.push_back(0.0);
     }
 
-    for ( size_t siteIndex = 0; siteIndex < this->nLoci(); siteIndex++ ){
-        for (size_t i = 0; i < prob[siteIndex].size(); i++){
+    for ( size_t siteIndex = 0; siteIndex < this->nLoci(); siteIndex++ ) {
+        for (size_t i = 0; i < prob[siteIndex].size(); i++) {
             this->ibdProbsIntegrated[i] += prob[siteIndex][i];
         }
     }
@@ -759,33 +856,85 @@ void DEploidIO::getIBDprobsIntegrated(vector < vector <double> > &prob){
 }
 
 
-void DEploidIO::computeEffectiveKstrain(vector <double> proportion){
+void DEploidIO::computeEffectiveKstrain(vector <double> proportion) {
     double tmpSumSq = 0.0;
-    for (double p : proportion){
+    for (double p : proportion) {
         tmpSumSq += p * p;
     }
     this->effectiveKstrain_ = 1.0 / tmpSumSq;
 }
 
 
-void DEploidIO::computeInferredKstrain(vector <double> proportion){
+void DEploidIO::computeInferredKstrain(vector <double> proportion) {
     this->inferredKstrain_ = 0;
-    for (double p : proportion){
-        if ( p > 0.01 ){
+    for (double p : proportion) {
+        if ( p > 0.01 ) {
             this->inferredKstrain_ += 1;
         }
     }
 }
 
 
-void DEploidIO::computeAdjustedEffectiveKstrain(){
+void DEploidIO::computeAdjustedEffectiveKstrain() {
     this->adjustedEffectiveKstrain_ = this->effectiveKstrain_;
-    if ( (this->inferredKstrain_ == 2) & (ibdProbsIntegrated.size() == 2)){
-        if ( this->ibdProbsIntegrated[1] > 0.95 ){
+    if ( (this->inferredKstrain_ == 2) & (ibdProbsIntegrated.size() == 2)) {
+        if ( this->ibdProbsIntegrated[1] > 0.95 ) {
             this->adjustedEffectiveKstrain_ = 1;
         }
     }
 }
 
 
+vector <double> DEploidIO::lassoComputeObsWsaf(size_t segmentStartIndex, size_t nLoci) {
+    vector <double> ret(nLoci, 0.0);
+    for ( size_t i = 0; i < nLoci; i++) {
+        size_t idx = i + segmentStartIndex;
+        ret[i] = this->altCount_[idx] / (this->refCount_[idx] + this->altCount_[idx] + 0.00000000000001);
+    }
+    return ret;
+}
+
+
+vector < vector <double> > DEploidIO::lassoSubsetPanel(size_t segmentStartIndex, size_t nLoci) {
+    vector < vector <double> > ret;
+    for ( size_t i = 0; i < nLoci; i++) {
+        size_t idx = i + segmentStartIndex;
+        ret.push_back(this->panel->content_[idx]);
+    }
+    return ret;
+}
+
+
+void DEploidIO::dEploidLasso() {
+    for ( size_t chromi = 0 ; chromi < this->indexOfChromStarts_.size(); chromi++ ) {
+        size_t start = this->indexOfChromStarts_[chromi];
+        size_t length = this->position_[chromi].size();
+        size_t end = start + length;
+        vector <double> wsaf = lassoComputeObsWsaf(start, length);
+        vector < vector <double> > tmpPanel = lassoSubsetPanel(start, length);
+        DEploidLASSO dummy(tmpPanel, wsaf, 250);
+        vector <string> newHeader;
+        for (size_t i = 0; i < dummy.choiceIdx.size(); i++) {
+            newHeader.push_back(panel->header_[dummy.choiceIdx[i]]);
+        }
+        Panel * tmp = new Panel(vecFromTo(this->panel->pRec_, start, end),
+                            vecFromTo(this->panel->pRecEachHap_, start, end),
+                            vecFromTo(this->panel->pNoRec_, start, end),
+                            vecFromTo(this->panel->pRecRec_, start, end),
+                            vecFromTo(this->panel->pRecNoRec_, start, end),
+                            vecFromTo(this->panel->pNoRecNoRec_, start, end),
+                            dummy.reducedPanel);
+        lassoPanels.push_back(tmp);
+        lassoPlafs.push_back(vecFromTo(plaf_, start, end));
+        lassoRefCount.push_back(vecFromTo(refCount_, start, end));
+        lassoAltCount.push_back(vecFromTo(altCount_, start, end));
+        if (this->doPrintLassoPanel()) {
+            this->writePanel(tmp, chromi, newHeader);
+        }
+    }
+    for ( auto const& value: this->initialProp ) {
+        this->finalProp.push_back(value);
+    }
+}
+
 
