@@ -27,22 +27,24 @@
 #ifndef TXTREADER
 #define TXTREADER
 
+#include <vector>
+#include <string>
 #include "variantIndex.hpp"
 #include "exceptions.hpp"
 
 class TxtReader : public VariantIndex {
-#ifdef UNITTEST
- friend class TestPanel;
- friend class TestTxtReader;
- friend class TestInitialHaplotypes;
-#endif
- friend class McmcMachinery;
- friend class UpdateSingleHap;
- friend class UpdatePairHap;
- friend class UpdateHap;
- friend class Panel;
- friend class DEploidIO;
-  private:
+    #ifdef UNITTEST
+    friend class TestPanel;
+    friend class TestTxtReader;
+    friend class TestInitialHaplotypes;
+    #endif
+    friend class McmcMachinery;
+    friend class UpdateSingleHap;
+    friend class UpdatePairHap;
+    friend class UpdateHap;
+    friend class Panel;
+    friend class DEploidIO;
+ private:
     // Members
 
     // content is a matrix of n.loci by n.strains, i.e. content length is n.loci
@@ -51,33 +53,35 @@ class TxtReader : public VariantIndex {
     // info_ only refers to the first column of the content
     vector <double> info_;
 
+    vector <string> header_;
     size_t nInfoLines_;
 
     int tmpChromInex_;
     vector < int > tmpPosition_;
 
     // Methods
-    void extractChrom( string & tmp_str );
-    void extractPOS ( string & tmp_str );
+    void extractChrom(const string & tmp_str);
+    void extractPOS(const string & tmp_str);
+    void extractHeader(const string &line);
     void reshapeContentToInfo();
     string fileName;
 
-  public: // move the following to private
-    TxtReader (){};
-    virtual void readFromFile( const char inchar[] ){ this->readFromFileBase( inchar ); };
-    void readFromFileBase( const char inchar[] );
-    virtual ~TxtReader(){ };
-    void removeMarkers ( );
+ public:  // move the following to private
+    TxtReader() {}
+    virtual void readFromFile(const char inchar[]) {
+        this->readFromFileBase(inchar); }
+    void readFromFileBase(const char inchar[]);
+    virtual ~TxtReader() {}
+    void removeMarkers();
 };
 
 
 
 
 class ExcludeMarker : public TxtReader {
-  // sorting
-  public:
-    ExcludeMarker():TxtReader(){};
-    ~ExcludeMarker(){};
+ public:
+    ExcludeMarker():TxtReader() {}
+    ~ExcludeMarker() {}
 };
 
 
