@@ -27,7 +27,7 @@
 #include <algorithm>    // std::reverse
 #include <cstdlib>      // div
 
-UpdateHap::~UpdateHap(){}
+UpdateHap::~UpdateHap() {}
 
 UpdateHap::UpdateHap( vector <double> &refCount,
                       vector <double> &altCount,
@@ -40,12 +40,11 @@ UpdateHap::UpdateHap( vector <double> &refCount,
                       size_t nLoci,
                       Panel* panel,
                       double missCopyProb,
-                      double scalingFactor){
-
+                      double scalingFactor) {
     this->panel_ = panel;
     this->nPanel_ = 0; // Initialize when panel is not given
 
-    if ( this->panel_ != NULL ){
+    if ( this->panel_ != NULL ) {
         this->setPanelSize( this->panel_->truePanelSize() );
     }
 
@@ -67,17 +66,17 @@ void UpdateHap::core(vector <double> &refCount,
                            vector <double> &plaf,
                            vector <double> &expectedWsaf,
                            vector <double> &proportion,
-                           vector < vector <double> > &haplotypes ){ throw VirtualFunctionShouldNotBeCalled();};
-void UpdateHap::calcExpectedWsaf( vector <double> & expectedWsaf, vector <double> &proportion, vector < vector <double> > &haplotypes){ throw VirtualFunctionShouldNotBeCalled(); };
-void UpdateHap::calcHapLLKs( vector <double> &refCount, vector <double> &altCount){ throw VirtualFunctionShouldNotBeCalled();};
-void UpdateHap::buildEmission( double missCopyProb ){ throw VirtualFunctionShouldNotBeCalled();};
-void UpdateHap::samplePaths(){ throw VirtualFunctionShouldNotBeCalled();};
-void UpdateHap::addMissCopying( double missCopyProb ){ throw VirtualFunctionShouldNotBeCalled();};
-void UpdateHap::updateLLK(){ throw VirtualFunctionShouldNotBeCalled();};
-void UpdateHap::sampleHapIndependently(vector <double> &plaf){ throw VirtualFunctionShouldNotBeCalled();};
+                           vector < vector <double> > &haplotypes ) { throw VirtualFunctionShouldNotBeCalled();};
+void UpdateHap::calcExpectedWsaf( vector <double> & expectedWsaf, vector <double> &proportion, vector < vector <double> > &haplotypes) { throw VirtualFunctionShouldNotBeCalled(); };
+void UpdateHap::calcHapLLKs( vector <double> &refCount, vector <double> &altCount) { throw VirtualFunctionShouldNotBeCalled();};
+void UpdateHap::buildEmission( double missCopyProb ) { throw VirtualFunctionShouldNotBeCalled();};
+void UpdateHap::samplePaths() { throw VirtualFunctionShouldNotBeCalled();};
+void UpdateHap::addMissCopying( double missCopyProb ) { throw VirtualFunctionShouldNotBeCalled();};
+void UpdateHap::updateLLK() { throw VirtualFunctionShouldNotBeCalled();};
+void UpdateHap::sampleHapIndependently(vector <double> &plaf) { throw VirtualFunctionShouldNotBeCalled();};
 
 
-UpdateSingleHap::~UpdateSingleHap(){
+UpdateSingleHap::~UpdateSingleHap() {
     //delete recombRg_;
     //delete recombLevel2Rg_;
     //delete missCopyRg_;
@@ -95,7 +94,7 @@ UpdateSingleHap::UpdateSingleHap( vector <double> &refCount,
                                   size_t nLoci,
                                   Panel* panel, double missCopyProb, double scalingFactor,
                                   size_t strainIndex ):
-                UpdateHap(refCount, altCount, expectedWsaf, plaf, proportion, haplotypes, rg, segmentStartIndex, nLoci, panel, missCopyProb, scalingFactor){
+                UpdateHap(refCount, altCount, expectedWsaf, plaf, proportion, haplotypes, rg, segmentStartIndex, nLoci, panel, missCopyProb, scalingFactor) {
     this->strainIndex_ = strainIndex;
     siteOfOneSwitchOne = vector <double>(nLoci);
     siteOfOneMissCopyOne = vector <double>(nLoci);
@@ -107,12 +106,12 @@ void UpdateSingleHap::core(vector <double> &refCount,
                            vector <double> &plaf,
                            vector <double> &expectedWsaf,
                            vector <double> &proportion,
-                           vector < vector <double> > &haplotypes ){
+                           vector < vector <double> > &haplotypes ) {
 
     this->calcExpectedWsaf( expectedWsaf, proportion, haplotypes);
     this->calcHapLLKs(refCount, altCount);
 
-    if ( this->panel_ != NULL ){
+    if ( this->panel_ != NULL ) {
         this->buildEmission( this->missCopyProb_ );
         this->calcFwdProbs();
         this->samplePaths();
@@ -129,7 +128,7 @@ void UpdateSingleHap::painting( vector <double> &refCount,
                                 vector <double> &altCount,
                                 vector <double> &expectedWsaf,
                                 vector <double> &proportion,
-                                vector < vector <double> > &haplotypes ){
+                                vector < vector <double> > &haplotypes ) {
     this->calcExpectedWsaf( expectedWsaf, proportion, haplotypes);
     this->calcHapLLKs(refCount, altCount);
     this->buildEmission( this->missCopyProb_ );
@@ -137,9 +136,9 @@ void UpdateSingleHap::painting( vector <double> &refCount,
 }
 
 
-void UpdateSingleHap::calcBwdProbs(){
+void UpdateSingleHap::calcBwdProbs() {
     vector <double> bwdLast (this->nPanel_, 0.0);
-    for ( size_t i = 0 ; i < this->nPanel_; i++){
+    for ( size_t i = 0 ; i < this->nPanel_; i++) {
         //bwdLast[i] = this->emission_[0][this->panel_->content_[hapIndex][i]];
         //bwdLast[i] = 1.0 / (double)this->nPanel_;
         bwdLast[i] = 1.0;
@@ -149,17 +148,17 @@ void UpdateSingleHap::calcBwdProbs(){
     bwdProbs_.push_back(bwdLast);
 
     int j = (this->nLoci_- 1);
-    while (j > 0 ){
+    while (j > 0 ) {
         size_t hapIndexBack = this->segmentStartIndex_ + j;
         //double massFromRec = sumOfVec(bwdProbs_.back()) * pRecEachHap;
         vector <double> bwdTmp (this->nPanel_, 1.0);
         double pRecEachHap = this->panel_->pRecEachHap_[hapIndexBack-1];
         double pNoRec = this->panel_->pNoRec_[hapIndexBack-1];
-        for ( size_t i = 0 ; i < this->nPanel_; i++){
+        for ( size_t i = 0 ; i < this->nPanel_; i++) {
             bwdTmp[i] = 0.0;
-            for ( size_t ii = 0 ; ii < this->nPanel_; ii++){
+            for ( size_t ii = 0 ; ii < this->nPanel_; ii++) {
                 bwdTmp[i] += this->emission_[j][this->panel_->content_[hapIndexBack][ii]] * bwdProbs_.back()[ii] * pRecEachHap;
-                if ( i == ii){
+                if ( i == ii) {
                     bwdTmp[i] += this->emission_[j][this->panel_->content_[hapIndexBack][ii]] * bwdProbs_.back()[ii] * pNoRec;
                 }
             }
@@ -168,20 +167,20 @@ void UpdateSingleHap::calcBwdProbs(){
         bwdProbs_.push_back(bwdTmp);
         j--;
     }
-    if (bwdProbs_.size() != nLoci_){
+    if (bwdProbs_.size() != nLoci_) {
         throw LociNumberUnequal("here");
     }
     assert ( bwdProbs_.size() == nLoci_ );
 }
 
-void UpdateSingleHap::calcFwdBwdProbs(){
+void UpdateSingleHap::calcFwdBwdProbs() {
     this->calcFwdProbs();
     this->calcBwdProbs();
 
     assert (this->fwdBwdProbs_.size() == 0);
     for ( size_t j = 0; j < this->nLoci_; j++ ) {
         vector <double> fwdBwdTmp (this->nPanel_, 0.0);
-        for ( size_t i = 0 ; i < this->nPanel_; i++ ){
+        for ( size_t i = 0 ; i < this->nPanel_; i++ ) {
             fwdBwdTmp[i] = this->fwdProbs_[j][i] * bwdProbs_[this->nLoci_-j-1][i];
         }
         (void)normalizeBySum(fwdBwdTmp);
@@ -190,20 +189,20 @@ void UpdateSingleHap::calcFwdBwdProbs(){
     assert (this->fwdBwdProbs_.size() == nLoci_ );
 }
 
-void UpdateSingleHap::calcExpectedWsaf( vector <double> & expectedWsaf, vector <double> &proportion, vector < vector <double> > &haplotypes ){
+void UpdateSingleHap::calcExpectedWsaf( vector <double> & expectedWsaf, vector <double> &proportion, vector < vector <double> > &haplotypes ) {
     //expected.WSAF.0 <- bundle$expected.WSAF - (bundle$prop[ws] * bundle$h[,ws]);
     assert ( expectedWsaf0_.size() == 0);
     assert ( expectedWsaf1_.size() == 0);
     this->expectedWsaf0_ = vector <double> (expectedWsaf.begin()+this->segmentStartIndex_, expectedWsaf.begin()+(this->segmentStartIndex_+this->nLoci_));
     size_t hapIndex = this->segmentStartIndex_;
-    for ( size_t i = 0; i < expectedWsaf0_.size(); i++ ){
+    for ( size_t i = 0; i < expectedWsaf0_.size(); i++ ) {
         expectedWsaf0_[i] -= proportion[strainIndex_] * haplotypes[hapIndex][strainIndex_];
-        //if (expectedWsaf0_[i] <= 0 ){
+        //if (expectedWsaf0_[i] <= 0 ) {
             //cout << "i=" << i<<", expectedWsaf0_[i] = "<< expectedWsaf0_[i]<<", proportion[strainIndex_] = "<<proportion[strainIndex_]<<", haplotypes[hapIndex][strainIndex_] = "<<haplotypes[hapIndex][strainIndex_];
             //cout << ", expectedWsaf[hapIndex] = "<<expectedWsaf[hapIndex]<<endl;
         //}
         assert (expectedWsaf0_[i] >= 0 );
-        //if (expectedWsaf0_[i] >= 1 ){
+        //if (expectedWsaf0_[i] >= 1 ) {
             //cout << "i=" << i<<", expectedWsaf0_[i] = "<< expectedWsaf0_[i]<<", proportion[strainIndex_] = "<<proportion[strainIndex_]<<", haplotypes[hapIndex][strainIndex_]"<<haplotypes[hapIndex][strainIndex_] << endl;
         //}
         assert (expectedWsaf0_[i] <= 1 );
@@ -212,7 +211,7 @@ void UpdateSingleHap::calcExpectedWsaf( vector <double> & expectedWsaf, vector <
 
     //expected.WSAF.1 <- expected.WSAF.0 + bundle$prop[ws] ;
     this->expectedWsaf1_ = expectedWsaf0_;
-    for ( size_t i = 0; i < expectedWsaf1_.size(); i++ ){
+    for ( size_t i = 0; i < expectedWsaf1_.size(); i++ ) {
         expectedWsaf1_[i] += proportion[strainIndex_] ;
         assert (expectedWsaf1_[i] >= 0 );
     }
@@ -221,7 +220,7 @@ void UpdateSingleHap::calcExpectedWsaf( vector <double> & expectedWsaf, vector <
 }
 
 
-void UpdateSingleHap::buildEmission( double missCopyProb ){
+void UpdateSingleHap::buildEmission( double missCopyProb ) {
     vector <double> noMissProb (this->nLoci_, log(1.0 - missCopyProb));
     vector <double> t1omu = vecSum(llk0_, noMissProb); // t1 one minus u
     vector <double> t2omu = vecSum(llk1_, noMissProb); // t2 one minus u
@@ -232,7 +231,7 @@ void UpdateSingleHap::buildEmission( double missCopyProb ){
     vector <double> t2u = vecSum(llk1_, missProb);
 
     assert(emission_.size() == 0 );
-    for ( size_t i = 0; i < this->nLoci_; i++){
+    for ( size_t i = 0; i < this->nLoci_; i++) {
         vector <double> tmp ({t1omu[i], t2omu[i], t1u[i], t2u[i]});
         double tmaxTmp = max_value(tmp);
         vector <double> emissRow ({exp(t1omu[i] - tmaxTmp) + exp(t2u[i] - tmaxTmp),
@@ -244,9 +243,9 @@ void UpdateSingleHap::buildEmission( double missCopyProb ){
 }
 
 
-void UpdateSingleHap::buildEmissionBasicVersion( double missCopyProb ){
+void UpdateSingleHap::buildEmissionBasicVersion( double missCopyProb ) {
     assert(emission_.size() == 0 );
-    for ( size_t i = 0; i < this->nLoci_; i++){
+    for ( size_t i = 0; i < this->nLoci_; i++) {
         vector <double> emissRow ({exp(llk0_[i])*(1.0-missCopyProb) + exp(llk1_[i])*missCopyProb,
                                    exp(llk1_[i])*(1.0-missCopyProb) + exp(llk0_[i])*missCopyProb});
 
@@ -255,11 +254,11 @@ void UpdateSingleHap::buildEmissionBasicVersion( double missCopyProb ){
 }
 
 
-void UpdateSingleHap::calcFwdProbs(){
+void UpdateSingleHap::calcFwdProbs() {
     size_t hapIndex = this->segmentStartIndex_;
     assert ( this->fwdProbs_.size() == 0 );
     vector <double> fwd1st (this->nPanel_, 0.0);
-    for ( size_t i = 0 ; i < this->nPanel_; i++){
+    for ( size_t i = 0 ; i < this->nPanel_; i++) {
         fwd1st[i] = this->emission_[0][this->panel_->content_[hapIndex][i]];
     }
     (void)normalizeBySum(fwd1st);
@@ -267,16 +266,16 @@ void UpdateSingleHap::calcFwdProbs(){
 
     //double inbreedProb = 0.0;
 
-    for ( size_t j = 1; j < this->nLoci_; j++ ){
+    for ( size_t j = 1; j < this->nLoci_; j++ ) {
         double pRecEachHap = this->panel_->pRecEachHap_[hapIndex];
         double pNoRec = this->panel_->pNoRec_[hapIndex];
         hapIndex++;
 
         double massFromRec = sumOfVec(fwdProbs_.back()) * pRecEachHap;
         vector <double> fwdTmp (this->nPanel_, 0.0);
-        for ( size_t i = 0 ; i < this->nPanel_; i++){
+        for ( size_t i = 0 ; i < this->nPanel_; i++) {
             fwdTmp[i] = this->emission_[j][this->panel_->content_[hapIndex][i]] * (fwdProbs_.back()[i] * pNoRec + massFromRec);
-            //if ( i >= this->panel_->truePanelSize() ){
+            //if ( i >= this->panel_->truePanelSize() ) {
                 //fwdTmp[i] = this->emission_[j][this->panel_->content_[hapIndex][i]] * (fwdProbs_.back()[i] * pNoRec + massFromRec) * inbreedProb;
             //} else {
                 //fwdTmp[i] = this->emission_[j][this->panel_->content_[hapIndex][i]] * (fwdProbs_.back()[i] * pNoRec + massFromRec);
@@ -290,7 +289,7 @@ void UpdateSingleHap::calcFwdProbs(){
 
 
 void UpdateSingleHap::calcHapLLKs( vector <double> &refCount,
-                                   vector <double> &altCount){
+                                   vector <double> &altCount) {
     this->llk0_ = calcLLKs( refCount, altCount, expectedWsaf0_, this->segmentStartIndex_, this->nLoci_, this->scalingFactor() );
     this->llk1_ = calcLLKs( refCount, altCount, expectedWsaf1_, this->segmentStartIndex_, this->nLoci_, this->scalingFactor() );
     assert( this->llk0_.size() == this->nLoci_ );
@@ -298,7 +297,7 @@ void UpdateSingleHap::calcHapLLKs( vector <double> &refCount,
 }
 
 
-void UpdateSingleHap::samplePaths(){
+void UpdateSingleHap::samplePaths() {
     assert ( this->path_.size() == 0 );
     // Sample path at the last position
     size_t pathTmp = sampleIndexGivenProp ( this->recombRg_, fwdProbs_.back() );
@@ -306,7 +305,7 @@ void UpdateSingleHap::samplePaths(){
 
     this->path_.push_back( this->panel_->content_[contentIndex][pathTmp]);
 
-    for ( size_t j = (this->nLoci_ - 1) ; j > 0; j-- ){
+    for ( size_t j = (this->nLoci_ - 1) ; j > 0; j-- ) {
         contentIndex--;
         double pRecEachHap = this->panel_->pRecEachHap_[contentIndex];
         double pNoRec = this->panel_->pNoRec_[contentIndex];
@@ -318,7 +317,7 @@ void UpdateSingleHap::samplePaths(){
                                                sumOfVec(previousDist)*pRecEachHap});
         (void)normalizeBySum(weightOfNoRecAndRec);
 
-        if ( sampleIndexGivenProp(this->recombRg_, weightOfNoRecAndRec) == (size_t)1 ){ // Switch one
+        if ( sampleIndexGivenProp(this->recombRg_, weightOfNoRecAndRec) == (size_t)1 ) { // Switch one
             pathTmp = sampleIndexGivenProp( this->recombLevel2Rg_, previousDist );
             this->siteOfOneSwitchOne[j] += 1.0;
         }
@@ -331,16 +330,16 @@ void UpdateSingleHap::samplePaths(){
 }
 
 
-void UpdateSingleHap::addMissCopying( double missCopyProb ){
+void UpdateSingleHap::addMissCopying( double missCopyProb ) {
     assert( this->hap_.size() == 0 );
-    for ( size_t i = 0; i < this->nLoci_; i++){
+    for ( size_t i = 0; i < this->nLoci_; i++) {
         double tmpMax = max_value ( vector <double>({this->llk0_[i], this->llk1_[i]}));
         vector <double> emissionTmp ({exp(this->llk0_[i]-tmpMax), exp(this->llk1_[i]-tmpMax)});
         vector <double> sameDiffDist ({emissionTmp[path_[i]]*(1.0 - missCopyProb), // probability of the same
                                        emissionTmp[(size_t)(1 -path_[i])] * missCopyProb }); // probability of differ
 
         (void)normalizeBySum(sameDiffDist);
-        if ( sampleIndexGivenProp( this->missCopyRg_, sameDiffDist) == 1 ){
+        if ( sampleIndexGivenProp( this->missCopyRg_, sameDiffDist) == 1 ) {
             this->hap_.push_back( 1 - this->path_[i] ); // differ
             this->siteOfOneMissCopyOne[i] += 1.0;
         } else {
@@ -351,10 +350,10 @@ void UpdateSingleHap::addMissCopying( double missCopyProb ){
 }
 
 
-void UpdateSingleHap::sampleHapIndependently( vector <double> &plaf ){
+void UpdateSingleHap::sampleHapIndependently( vector <double> &plaf ) {
     assert( this->hap_.size() == 0 );
     size_t plafIndex = this->segmentStartIndex_;
-    for ( size_t i = 0; i < this->nLoci_; i++){
+    for ( size_t i = 0; i < this->nLoci_; i++) {
         double tmpMax = max_value ( vector <double> ( {llk0_[i], llk1_[i]} ) ) ;
         vector <double> tmpDist ( {exp(llk0_[i] - tmpMax) * (1.0-plaf[plafIndex]),
                                    exp(llk1_[i] - tmpMax) * plaf[plafIndex] } );
@@ -366,12 +365,12 @@ void UpdateSingleHap::sampleHapIndependently( vector <double> &plaf ){
 }
 
 
-void UpdateSingleHap::updateLLK(){
+void UpdateSingleHap::updateLLK() {
     newLLK = vector <double> (this->nLoci_, 0.0);
-    for ( size_t i = 0; i < this->nLoci_; i++){
-        if ( this->hap_[i] == 0){
+    for ( size_t i = 0; i < this->nLoci_; i++) {
+        if ( this->hap_[i] == 0) {
             newLLK[i] = llk0_[i];
-        } else if (this->hap_[i] == 1){
+        } else if (this->hap_[i] == 1) {
             newLLK[i] = llk1_[i];
         } else {
             throw ShouldNotBeCalled();
@@ -380,7 +379,7 @@ void UpdateSingleHap::updateLLK(){
 }
 
 
-UpdatePairHap::~UpdatePairHap(){
+UpdatePairHap::~UpdatePairHap() {
     //delete recombRg_;
     //delete recombLevel2Rg_;
     //delete missCopyRg_;
@@ -399,7 +398,7 @@ UpdatePairHap::UpdatePairHap( vector <double> &refCount,
                               bool forbidCopyFromSame,
                               size_t strainIndex1,
                               size_t strainIndex2 ):
-                UpdateHap(refCount, altCount, plaf, expectedWsaf, proportion, haplotypes, rg, segmentStartIndex, nLoci, panel, missCopyProb, scalingFactor){
+                UpdateHap(refCount, altCount, plaf, expectedWsaf, proportion, haplotypes, rg, segmentStartIndex, nLoci, panel, missCopyProb, scalingFactor) {
     this->strainIndex1_ = strainIndex1;
     this->strainIndex2_ = strainIndex2;
     this->forbidCopyFromSame_ = forbidCopyFromSame;
@@ -415,12 +414,11 @@ void UpdatePairHap::core(vector <double> &refCount,
                            vector <double> &plaf,
                            vector <double> &expectedWsaf,
                            vector <double> &proportion,
-                           vector < vector <double> > &haplotypes){
+                           vector < vector <double> > &haplotypes) {
 
     this->calcExpectedWsaf( expectedWsaf, proportion, haplotypes);
     this->calcHapLLKs(refCount, altCount);
-
-    if ( this->panel_ != NULL ){
+    if ( this->panel_ != NULL ) {
         this->buildEmission(this->missCopyProb_);
         this->calcFwdProbs(this->forbidCopyFromSame_);
         this->samplePaths();
@@ -428,19 +426,18 @@ void UpdatePairHap::core(vector <double> &refCount,
     } else {
         this->sampleHapIndependently( plaf );
     }
-
     this->updateLLK();
 }
 
 
-void UpdatePairHap:: calcExpectedWsaf( vector <double> & expectedWsaf, vector <double> &proportion, vector < vector <double> > &haplotypes){
+void UpdatePairHap:: calcExpectedWsaf( vector <double> & expectedWsaf, vector <double> &proportion, vector < vector <double> > &haplotypes) {
   //expected.WSAF.00 <- expected.WSAF-(prop[ws[1]]*h[,ws[1]] + prop[ws[2]]*h[,ws[2]]);
   //expected.WSAF.10 <- expected.WSAF.00 + prop[ws[1]];
   //expected.WSAF.01 <- expected.WSAF.00 + prop[ws[2]];
   //expected.WSAF.11 <- expected.WSAF.00 + prop[ws[1]] + prop[ws[2]];    //expected.WSAF.0 <- bundle$expected.WSAF - (bundle$prop[ws] * bundle$h[,ws]);
     this->expectedWsaf00_ = vector <double> (expectedWsaf.begin()+this->segmentStartIndex_, expectedWsaf.begin()+(this->segmentStartIndex_+this->nLoci_));
     size_t hapIndex = this->segmentStartIndex_;
-    for ( size_t i = 0; i < expectedWsaf00_.size(); i++ ){
+    for ( size_t i = 0; i < expectedWsaf00_.size(); i++ ) {
         expectedWsaf00_[i] -= (proportion[strainIndex1_] * haplotypes[hapIndex][strainIndex1_] + proportion[strainIndex2_] * haplotypes[hapIndex][strainIndex2_]);
         //dout << expectedWsaf[i] << " " << expectedWsaf00_[i] << endl;
         assert (expectedWsaf00_[i] >= 0 );
@@ -449,23 +446,23 @@ void UpdatePairHap:: calcExpectedWsaf( vector <double> & expectedWsaf, vector <d
     }
 
     this->expectedWsaf10_ = expectedWsaf00_;
-    for ( size_t i = 0; i < expectedWsaf10_.size(); i++ ){
+    for ( size_t i = 0; i < expectedWsaf10_.size(); i++ ) {
         expectedWsaf10_[i] += proportion[strainIndex1_] ;
     }
 
     this->expectedWsaf01_ = expectedWsaf00_;
-    for ( size_t i = 0; i < expectedWsaf01_.size(); i++ ){
+    for ( size_t i = 0; i < expectedWsaf01_.size(); i++ ) {
         expectedWsaf01_[i] += proportion[strainIndex2_] ;
     }
 
     this->expectedWsaf11_ = expectedWsaf00_;
-    for ( size_t i = 0; i < expectedWsaf11_.size(); i++ ){
+    for ( size_t i = 0; i < expectedWsaf11_.size(); i++ ) {
         expectedWsaf11_[i] += (proportion[strainIndex1_] + proportion[strainIndex2_]);
     }
 }
 
 
-void UpdatePairHap:: calcHapLLKs( vector <double> &refCount, vector <double> &altCount){
+void UpdatePairHap:: calcHapLLKs( vector <double> &refCount, vector <double> &altCount) {
     this->llk00_ = calcLLKs( refCount, altCount, expectedWsaf00_, this->segmentStartIndex_, this->nLoci_, this->scalingFactor() );
     this->llk10_ = calcLLKs( refCount, altCount, expectedWsaf10_, this->segmentStartIndex_, this->nLoci_, this->scalingFactor() );
     this->llk01_ = calcLLKs( refCount, altCount, expectedWsaf01_, this->segmentStartIndex_, this->nLoci_, this->scalingFactor() );
@@ -477,7 +474,7 @@ void UpdatePairHap:: calcHapLLKs( vector <double> &refCount, vector <double> &al
 }
 
 
-void UpdatePairHap:: buildEmission( double missCopyProb ){
+void UpdatePairHap:: buildEmission( double missCopyProb ) {
     //llk.00 = logemiss[,1]
     //llk.10 = logemiss[,2]
     //llk.01 = logemiss[,3]
@@ -521,7 +518,7 @@ void UpdatePairHap:: buildEmission( double missCopyProb ){
                     //exp( tmp.11.1-tmp.max ) + exp( tmp.11.2-tmp.max ) + exp( tmp.11.3-tmp.max ) + exp( tmp.11.4-tmp.max ))
 
     assert(this->emission_.size() == 0 );
-    for ( size_t i = 0; i < this->nLoci_; i++){
+    for ( size_t i = 0; i < this->nLoci_; i++) {
         vector <double> tmp ({tmp_00_1[i], tmp_00_2[i], tmp_00_3[i], tmp_00_4[i],
                               tmp_01_1[i], tmp_01_2[i], tmp_01_3[i], tmp_01_4[i],
                               tmp_10_1[i], tmp_10_2[i], tmp_10_3[i], tmp_10_4[i],
@@ -538,9 +535,9 @@ void UpdatePairHap:: buildEmission( double missCopyProb ){
 }
 
 
-vector <double> UpdatePairHap::computeRowMarginalDist( vector < vector < double > > & probDist ){ // Sum of Rows
+vector <double> UpdatePairHap::computeRowMarginalDist( vector < vector < double > > & probDist ) { // Sum of Rows
     vector <double> marginalDist (probDist.size(), 0.0);
-    for ( size_t i = 0; i < probDist.size(); i++ ){
+    for ( size_t i = 0; i < probDist.size(); i++ ) {
         marginalDist[i] = sumOfVec(probDist[i]);
     }
     //assert ( sumOfVec (marginalDist) == sumOfMat(probDist));
@@ -548,10 +545,10 @@ vector <double> UpdatePairHap::computeRowMarginalDist( vector < vector < double
 }
 
 
-vector <double> UpdatePairHap::computeColMarginalDist( vector < vector < double > > & probDist ){ // Sum of Cols
+vector <double> UpdatePairHap::computeColMarginalDist( vector < vector < double > > & probDist ) { // Sum of Cols
     vector <double> marginalDist (probDist.size(), 0.0);
-    for ( size_t coli = 0; coli < probDist[0].size(); coli++ ){
-        for ( size_t rowi = 0; rowi < probDist.size(); rowi++ ){
+    for ( size_t coli = 0; coli < probDist[0].size(); coli++ ) {
+        for ( size_t rowi = 0; rowi < probDist.size(); rowi++ ) {
             marginalDist[coli] += probDist[rowi][coli];
         }
     }
@@ -561,18 +558,18 @@ vector <double> UpdatePairHap::computeColMarginalDist( vector < vector < double
 }
 
 
-void UpdatePairHap:: calcFwdProbs( bool forbidCopyFromSame ){
+void UpdatePairHap:: calcFwdProbs( bool forbidCopyFromSame ) {
     size_t hapIndex = this->segmentStartIndex_;
     assert ( this->fwdProbs_.size() == 0 );
     vector < vector < double > > fwd1st;
-    for ( size_t i = 0 ; i < this->nPanel_; i++){ // Row of the matrix
+    for ( size_t i = 0 ; i < this->nPanel_; i++) {  // Row of the matrix
         size_t rowObs = (size_t)this->panel_->content_[0][i];
         vector <double> fwd1stRow (this->nPanel_, 0.0);
 
-        for ( size_t ii = 0 ; ii < this->nPanel_; ii++){ // Column of the matrix
+        for ( size_t ii = 0 ; ii < this->nPanel_; ii++) {  // Column of the matrix
             if ( forbidCopyFromSame && i == ii ) continue;
+            size_t colObs = static_cast<size_t>(this->panel_->content_[hapIndex][ii]);
 
-            size_t colObs = (size_t)this->panel_->content_[hapIndex][ii];
             size_t obs = rowObs*2 + colObs;
             fwd1stRow[ii] = this->emission_[0][obs];
         }
@@ -580,8 +577,7 @@ void UpdatePairHap:: calcFwdProbs( bool forbidCopyFromSame ){
     }
     (void)normalizeBySumMat(fwd1st);
     this->fwdProbs_.push_back(fwd1st);
-
-    for ( size_t j = 1; j < this->nLoci_; j++ ){
+    for ( size_t j = 1; j < this->nLoci_; j++ ) {
         double recRec = this->panel_->pRecRec_[hapIndex];
         double recNorec = this->panel_->pRecNoRec_[hapIndex];
         double norecNorec = this->panel_->pNoRecNoRec_[hapIndex];
@@ -591,10 +587,10 @@ void UpdatePairHap:: calcFwdProbs( bool forbidCopyFromSame ){
         vector <double> marginalOfCols = this->computeColMarginalDist( this->fwdProbs_.back() );
 
         vector < vector < double > > fwdTmp;
-        for ( size_t i = 0 ; i < this->nPanel_; i++){
+        for ( size_t i = 0 ; i < this->nPanel_; i++) {
             size_t rowObs = (size_t)this->panel_->content_[hapIndex][i];
             vector <double> fwdTmpRow (this->nPanel_, 0.0);
-            for ( size_t ii = 0 ; ii < this->nPanel_; ii++){
+            for ( size_t ii = 0 ; ii < this->nPanel_; ii++) {
                 if ( forbidCopyFromSame && i == ii ) continue;
 
                 size_t colObs = (size_t)this->panel_->content_[hapIndex][ii];
@@ -611,7 +607,7 @@ void UpdatePairHap:: calcFwdProbs( bool forbidCopyFromSame ){
 }
 
 
-vector <size_t> UpdatePairHap::sampleMatrixIndex( vector < vector < double > > &probDist ){
+vector <size_t> UpdatePairHap::sampleMatrixIndex( vector < vector < double > > &probDist ) {
     size_t tmp = sampleIndexGivenProp ( this->recombLevel2Rg_, reshapeMatToVec(probDist));
     div_t divresult;
     divresult = div((int)tmp, (int)this->nPanel_);
@@ -619,7 +615,7 @@ vector <size_t> UpdatePairHap::sampleMatrixIndex( vector < vector < double > > &
 }
 
 
-void UpdatePairHap::samplePaths(){
+void UpdatePairHap::samplePaths() {
     assert ( this->path1_.size() == 0 );
     assert ( this->path2_.size() == 0 );
 
@@ -631,7 +627,7 @@ void UpdatePairHap::samplePaths(){
     this->path1_.push_back(this->panel_->content_[contentIndex][rowI]);
     this->path2_.push_back(this->panel_->content_[contentIndex][colJ]);
 
-    for ( size_t j = (this->nLoci_ - 1) ; j > 0; j-- ){
+    for ( size_t j = (this->nLoci_ - 1) ; j > 0; j-- ) {
         contentIndex--;
         double recRec = this->panel_->pRecRec_[contentIndex];
         double recNorec = this->panel_->pRecNoRec_[contentIndex];
@@ -645,7 +641,7 @@ void UpdatePairHap::samplePaths(){
         double tmpRowSum = sumOfVec(rowIdist);
 
         vector <double> colJdist;
-        for ( auto const& array: previousDist ){
+        for ( auto const& array: previousDist ) {
             colJdist.push_back( array[colJ] );
         }
         assert(this->nPanel_ == colJdist.size());
@@ -659,27 +655,27 @@ void UpdatePairHap::samplePaths(){
 
         size_t tmpCase = sampleIndexGivenProp( this->recombRg_, weightOfFourCases );
 
-        if ( tmpCase == (size_t)0 ){ // switching both strains
+        if ( tmpCase == (size_t)0 ) { // switching both strains
             this->siteOfTwoSwitchTwo[j] += 1.0;
             tmpPath = sampleMatrixIndex(previousDist);
             rowI = tmpPath[0];
             colJ = tmpPath[1];
             //assert (rowI != colJ); // OFF, as by default, allow copying the same strain
-        } else if ( tmpCase == (size_t)1 ){ // switching second strain
+        } else if ( tmpCase == (size_t)1 ) { // switching second strain
             this->siteOfTwoSwitchOne[j] += 0.5;
-            rowI = rowI;
+            //rowI = rowI;
             (void)normalizeBySum(rowIdist);
             colJ = sampleIndexGivenProp( this->recombLevel2Rg_, rowIdist );
             //assert (rowI != colJ); // OFF, as by default, allow copying the same strain
-        } else if ( tmpCase == (size_t)2 ){ // switching first strain
+        } else if ( tmpCase == (size_t)2 ) { // switching first strain
             this->siteOfTwoSwitchOne[j] += 0.5;
             (void)normalizeBySum(colJdist);
             rowI = sampleIndexGivenProp( this->recombLevel2Rg_, colJdist );
-            colJ = colJ;
+            //colJ = colJ;
             //assert (rowI != colJ); // OFF, as by default, allow copying the same strain
         } else if ( tmpCase == (size_t)3 ) { // no switching
-            rowI = rowI;
-            colJ = colJ;
+            //rowI = rowI;
+            //colJ = colJ;
             //assert (rowI != colJ); // OFF, as by default, allow copying the same strain
         } else {
             throw ShouldNotBeCalled();
@@ -696,11 +692,11 @@ void UpdatePairHap::samplePaths(){
 }
 
 
-void UpdatePairHap::addMissCopying( double missCopyProb ){
+void UpdatePairHap::addMissCopying( double missCopyProb ) {
     assert( this->hap1_.size() == 0 );
     assert( this->hap2_.size() == 0 );
 
-    for ( size_t i = 0; i < this->nLoci_; i++){
+    for ( size_t i = 0; i < this->nLoci_; i++) {
         double tmpMax = max_value ( vector <double>({this->llk00_[i], this->llk01_[i], this->llk10_[i], this->llk11_[i]}));
         vector <double> emissionTmp ({exp(this->llk00_[i]-tmpMax), exp(this->llk01_[i]-tmpMax), exp(this->llk10_[i]-tmpMax), exp(this->llk11_[i]-tmpMax)});
         vector <double> casesDist ( { emissionTmp[(size_t)(2*path1_[i]     +path2_[i])]     * (1.0 - missCopyProb) * (1.0 - missCopyProb), // probability of both same
@@ -710,18 +706,18 @@ void UpdatePairHap::addMissCopying( double missCopyProb ){
         (void)normalizeBySum(casesDist);
         size_t tmpCase = sampleIndexGivenProp( this->missCopyRg_, casesDist );
 
-        if ( tmpCase == 0 ){
+        if ( tmpCase == 0 ) {
             this->hap1_.push_back( this->path1_[i] );
             this->hap2_.push_back( this->path2_[i] );
-        } else if ( tmpCase == 1 ){
+        } else if ( tmpCase == 1 ) {
             this->siteOfTwoMissCopyOne[i] += 0.5;
             this->hap1_.push_back( this->path1_[i] );
             this->hap2_.push_back( 1.0 - this->path2_[i] );
-        } else if ( tmpCase == 2 ){
+        } else if ( tmpCase == 2 ) {
             this->siteOfTwoMissCopyOne[i] += 0.5;
             this->hap1_.push_back( 1.0 - this->path1_[i] );
             this->hap2_.push_back( this->path2_[i] );
-        } else if ( tmpCase == 3 ){
+        } else if ( tmpCase == 3 ) {
             this->siteOfTwoMissCopyTwo[i] += 1.0;
             this->hap1_.push_back( 1.0 - this->path1_[i] );
             this->hap2_.push_back( 1.0 - this->path2_[i] );
@@ -735,12 +731,12 @@ void UpdatePairHap::addMissCopying( double missCopyProb ){
 }
 
 
-void UpdatePairHap::sampleHapIndependently(vector <double> &plaf){
+void UpdatePairHap::sampleHapIndependently(vector <double> &plaf) {
     assert( this->hap1_.size() == 0 );
     assert( this->hap2_.size() == 0 );
 
     size_t plafIndex = this->segmentStartIndex_;
-    for ( size_t i = 0; i < this->nLoci_; i++){
+    for ( size_t i = 0; i < this->nLoci_; i++) {
         double tmpMax = max_value ( vector <double> ( {llk00_[i], llk01_[i], llk10_[i], llk11_[i]} ) );
         vector <double> tmpDist ( {exp(llk00_[i] - tmpMax) * (1.0-plaf[plafIndex]) * (1.0-plaf[plafIndex]),
                                    exp(llk01_[i] - tmpMax) * (1.0-plaf[plafIndex]) * plaf[plafIndex],
@@ -750,16 +746,16 @@ void UpdatePairHap::sampleHapIndependently(vector <double> &plaf){
 
         size_t tmpCase = sampleIndexGivenProp( this->recombRg_, tmpDist );
 
-        if ( tmpCase == 0 ){
+        if ( tmpCase == 0 ) {
             this->hap1_.push_back( 0.0 );
             this->hap2_.push_back( 0.0 );
-        } else if ( tmpCase == 1 ){
+        } else if ( tmpCase == 1 ) {
             this->hap1_.push_back( 0.0 );
             this->hap2_.push_back( 1.0 );
-        } else if ( tmpCase == 2 ){
+        } else if ( tmpCase == 2 ) {
             this->hap1_.push_back( 1.0 );
             this->hap2_.push_back( 0.0 );
-        } else if ( tmpCase == 3 ){
+        } else if ( tmpCase == 3 ) {
             this->hap1_.push_back( 1.0 );
             this->hap2_.push_back( 1.0 );
         } else {
@@ -773,16 +769,16 @@ void UpdatePairHap::sampleHapIndependently(vector <double> &plaf){
 }
 
 
-void UpdatePairHap::updateLLK(){
+void UpdatePairHap::updateLLK() {
     newLLK = vector <double> (this->nLoci_, 0.0);
-    for ( size_t i = 0; i < this->nLoci_; i++){
-        if ( this->hap1_[i] == 0 && this->hap2_[i] == 0 ){
+    for ( size_t i = 0; i < this->nLoci_; i++) {
+        if ( this->hap1_[i] == 0 && this->hap2_[i] == 0 ) {
             newLLK[i] = llk00_[i];
-        } else if (this->hap1_[i] == 0 && this->hap2_[i] == 1){
+        } else if (this->hap1_[i] == 0 && this->hap2_[i] == 1) {
             newLLK[i] = llk01_[i];
-        } else if (this->hap1_[i] == 1 && this->hap2_[i] == 0){
+        } else if (this->hap1_[i] == 1 && this->hap2_[i] == 0) {
             newLLK[i] = llk10_[i];
-        } else if (this->hap1_[i] == 1 && this->hap2_[i] == 1){
+        } else if (this->hap1_[i] == 1 && this->hap2_[i] == 1) {
             newLLK[i] = llk11_[i];
         } else {
             throw ShouldNotBeCalled();
